@@ -29,8 +29,8 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 from DLStudio import *
 
 dls = DLStudio(
-                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5/",
-#                  dataroot = "./data/",
+#                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5/",
+                  dataroot = "./data/",
                   image_size = [32,32],
                   path_saved_model = "./saved_model",
                   momentum = 0.9,
@@ -38,8 +38,6 @@ dls = DLStudio(
                   epochs = 4,
                   batch_size = 4,
                   classes = ('rectangle','triangle','disk','oval','star'),
-                  debug_train = 0,
-                  debug_test = 1,
                   use_gpu = True,
               )
 
@@ -61,8 +59,6 @@ detector.load_PurdueShapes5_dataset(dataserver_train, dataserver_test)
 
 model = detector.BMEnet(skip_connections=True, depth=32)
 
-dls.show_network_summary(model)
-
 detector.run_code_for_training_with_custom_loading(model)
 
 detector.run_code_for_testing_with_custom_loading(model)
