@@ -61,8 +61,6 @@ dls = DLStudio(
                   epochs = 2,
                   batch_size = 4,
                   classes = ('rectangle','triangle','disk','oval','star'),
-                  debug_train = 1,
-                  debug_test = 1,
                   use_gpu = True,
               )
 
@@ -72,17 +70,17 @@ dataserver_train = DLStudio.DetectAndLocalize.PurdueShapes5Dataset(
                                    train_or_test = 'train',
                                    dl_studio = dls,
 #                                   dataset_file = "PurdueShapes5-20-train.gz", 
-                                   dataset_file = "PurdueShapes5-10000-train-noise-20.gz", 
-#                                   dataset_file = "PurdueShapes5-10000-train-noise-50.gz", 
-#                                   dataset_file = "PurdueShapes5-10000-train-noise-80.gz", 
+                                   dataset_file = "PurdueShapes5-10000-train-noise-20.gz",          ## 20% noise
+#                                   dataset_file = "PurdueShapes5-10000-train-noise-50.gz",         ## 50% noise
+#                                   dataset_file = "PurdueShapes5-10000-train-noise-80.gz",         ## 80% noise
                                                                       )
 dataserver_test = DLStudio.DetectAndLocalize.PurdueShapes5Dataset(
                                    train_or_test = 'test',
                                    dl_studio = dls,
 #                                   dataset_file = "PurdueShapes5-20-test.gz"
-                                   dataset_file = "PurdueShapes5-1000-test-noise-20.gz"
-#                                   dataset_file = "PurdueShapes5-1000-test-noise-50.gz"
-#                                   dataset_file = "PurdueShapes5-1000-test-noise-80.gz"
+                                   dataset_file = "PurdueShapes5-1000-test-noise-20.gz"             ## 20% noise
+#                                   dataset_file = "PurdueShapes5-1000-test-noise-50.gz"            ## 50% noise
+#                                   dataset_file = "PurdueShapes5-1000-test-noise-80.gz"            ## 80% noise
                                                                   )
 detector.dataserver_train = dataserver_train
 detector.dataserver_test = dataserver_test
@@ -95,7 +93,7 @@ number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requ
 print("\n\nThe number of learnable parameters in the model: %d" % number_of_learnable_params)
 
 num_layers = len(list(model.parameters()))
-print("\n\nThe number of layers in the model: %d\n\n" % num_layers)
+print("\nThe number of layers in the model: %d\n\n" % num_layers)
 
 
 detector.run_code_for_training_with_CrossEntropy_and_MSE_Losses(model)
